AiiDA-FLEUR Data Plugins — AiiDA-FLEUR 1.1.1 documentation

# AiiDA-FLEUR Data Plugins

AiiDA-FLEUR data plugins include:

1. `FleurinpData` structure (FleurinpData)

2. `FleurinpModifier` structure (FleurinpModifier)

`FleurinpData` is a `Data` type that represents input files needed for the FLEUR code and methods to work with them. They include inp.xml and some other situational files. Finally, `FleurinpModifier` consists of methods to change existing `FleurinpData` in a way to preserve data provenance.

- FleurinpData
  - Description/Features
  - Properties
  - User Methods
  - Setting up atom labels
- FleurinpModifier
  - Description
  - Usage
  - User Methods
    - General methods
    - Modification registration methods